@@ -242,6 +242,10 @@ class TargetMetric(Enum):
 class InterpretabilityLevel(Enum):
     EXPLAINABLE = 2
     PRECISE = 0
+    STANDARD = 0
+    STANDARD_WITH_EXPLAINABILITY = 1
+    SIMPLE_WITH_EXPLAINABILITY = 2
+    LEAKAGE_DETECTION = 3
 
 
 class SplittingStrategy(Enum):
