@@ -274,6 +274,27 @@ class MyWhatify:
 
         return sens[alg]
 
+    @classmethod
+    def feature_importance_report(cls, ensemble_id):
+        logging.info('getting feature_importance report for ensemble_id: ' + str(ensemble_id))
+        return my_toolkit.Ensemble.get_feature_importance_report(id=ensemble_id)
+
+    @classmethod
+    def get_report_by_type(cls, report_type: str, entity_id: int):
+        logging.info(' '.join('getting report type:', str(report_type), 'for entity_id:', str(entity_id)))
+        return my_toolkit.Report.get_report(report_type=report_type, entity_id=entity_id)
+
+    @classmethod
+    def run_sensitivity(cls, ensemble_id):
+        logging.info('running model sensitivity for ensemble_id: ' + str(ensemble_id))
+        status = None
+        ensemble_id = int(ensemble_id)
+        if ensemble_id > 0:
+            status = my_toolkit.Ensemble.run_model_sensitivity(ensemble_id=ensemble_id)
+        else:
+            logging.info('invalid model sensitivity ensemble_id: ' + str(ensemble_id))
+        return status
+
     @classmethod
     def search_act_base(cls, searchfunc=None, search_term=None, len=10, action_func=None):
         delete_list = searchfunc(search_term=search_term, len=len)
@@ -314,6 +335,11 @@ class MyWhatify:
         logging.info('deleting task_id: ' + str(task_id))
         my_toolkit.Task.delete(task_id)
 
+    @classmethod
+    def cancel_task_by_id(cls, task_id):
+        logging.info('canceling task_id: ' + str(task_id))
+        my_toolkit.Task.cancel_task(task_id=task_id)
+
     @classmethod
     def delete_prediction_by_name(cls, prediction_name=None, len=10):
         logging.info('deleting prediction with prediction_name: ' + str(prediction_name))
@@ -451,7 +477,7 @@ class MyWhatify:
         return cls.get_pipeline_estimators_list(dataset_id, True, interpt_level)
 
     @classmethod
-    def get_pipeline_estimators_list(cls, dataset_id, interpt_level=Interpt.PRECISE):
+    def get_estimators_list(cls, dataset_id, interpt_level=Interpt.PRECISE):
         return cls.get_pipeline_estimators_list(dataset_id, False, interpt_level)
 
     @classmethod
@@ -638,6 +664,17 @@ class MyWhatify:
         with allure.step(' '.join(['getting wisdom ID:', str(wisdom_id)])):
             return my_toolkit.Wisdom.get_wisdom(id=wisdom_id)
 
+    @classmethod
+    def get_perturbations_download_link(cls, pred_id: int, features: str = None):
+        """
+        get perturbations download link for prediction
+        :param pred_id:prediction ID to get the download link
+        :param features: relvant features
+        :return: download link
+        """
+        with allure.step(' '.join(['getting perturbations download link for prediction ID:', str(pred_id), 'With Features: ', str(features)])):
+            return my_toolkit.Prediction.get_perturbations_download_link(pred_id=pred_id, features=features)
+
     #############################
     ###       Connector       ###
     #############################
